import fetch from "node-fetch";
import {FlowResponse, GeoProximity, UnitsType} from "./DataTypes";

const BASE_URL = "https://traffic.ls.hereapi.com";
const TRAFFIC_PATH = "traffic/6.1";

export class HereClient {
    constructor(
        private apiKey: string
    ) {}

    async flow(position: GeoProximity, units: UnitsType = "metric"): Promise<FlowResponse> {
        const prox = `${position.latitude},${position.longitude},${position.distance}`;
        const urlPath = `${TRAFFIC_PATH}/flow.json`;
        return this.get(urlPath, {prox, units});
    }

    private async get(urlPath: string, params: { [key: string]: string }): Promise<any> {
        let url = `${BASE_URL}/${urlPath}`;
        if (!params)
            params = {};
        params.apiKey = this.apiKey;
        params.responseattributes = "shape";
        url += "?";
        url += Object.entries(params)
            .map(([key, value]) => `${key}=${value}`)
            .join("&");
        return fetch(url).then(res => res.json());
    }
}
